import { EventEmitter } from '@angular/core';
import { SplitterType } from '../splitter.component';
import { IgxSplitterPaneComponent } from '../splitter-pane/splitter-pane.component';
import { IDragMoveEventArgs, IDragStartEventArgs, DragDirection } from '../../directives/drag-drop/drag-drop.directive';
export declare const SPLITTER_INTERACTION_KEYS: Set<string>;
/**
 * Provides reference to `SplitBarComponent` component.
 * Represents the draggable gripper that visually separates panes and allows for changing their sizes.
 * @export
 * @class SplitBarComponent
 */
export declare class IgxSplitBarComponent {
    /**
     * Sets/gets `IgxSplitBarComponent` orientation.
     * @type SplitterType
     */
    type: SplitterType;
    /**
     * Sets/gets `IgxSplitBarComponent` element order.
     * @type SplitterType
     */
    order: number;
    /**
     * @hidden
     * @internal
     */
    tabindex: number;
    /**
     * Sets/gets the `SplitPaneComponent` associated with the current `SplitBarComponent`.
     * @memberof SplitBarComponent
     */
    pane: IgxSplitterPaneComponent;
    /**
     * Sets/Gets the `SplitPaneComponent` sibling components associated with the current `SplitBarComponent`.
     */
    siblings: Array<IgxSplitterPaneComponent>;
    /**
     * An event that is emitted whenever we start dragging the current `SplitBarComponent`.
     * @memberof SplitBarComponent
     */
    moveStart: EventEmitter<IgxSplitterPaneComponent>;
    /**
     * An event that is emitted while we are dragging the current `SplitBarComponent`.
     * @memberof SplitBarComponent
     */
    moving: EventEmitter<number>;
    /**
     * An event that is emitted when collapsing the pane
     */
    togglePane: EventEmitter<IgxSplitterPaneComponent>;
    /**
     * A temporary holder for the pointer coordinates.
     * @private
     * @memberof SplitBarComponent
     */
    private startPoint;
    /**
     * @hidden @internal
     */
    get prevButtonHidden(): boolean;
    /**
     * @hidden @internal
     */
    keyEvent(event: KeyboardEvent): void;
    /**
     * @hidden @internal
     */
    get dragDir(): DragDirection.VERTICAL | DragDirection.HORIZONTAL;
    /**
     * @hidden @internal
     */
    get nextButtonHidden(): boolean;
    onDragStart(event: IDragStartEventArgs): void;
    onDragMove(event: IDragMoveEventArgs): void;
    protected get resizeDisallowed(): boolean;
    onCollapsing(next: boolean): void;
}
