import { ElementRef, EventEmitter } from '@angular/core';
/**
 * Provides reference to `SplitPaneComponent` component.
 * Represents individual resizable panes. Users can control the resize behavior via the min and max size properties.
 * @export
 * @class SplitPaneComponent
 */
export declare class IgxSplitterPaneComponent {
    private el;
    _size: string;
    /**
     * Sets/gets the size of the current `IgxSplitterPaneComponent`.
     */
    get size(): string;
    set size(value: string);
    /**
     * @hidden @internal
     */
    sizeChange: EventEmitter<string>;
    /**
     * Sets/gets the minimum allowable size of the current `IgxSplitterPaneComponent`.
     */
    minSize: string;
    /**
     * Sets/gets the maximum allowable size of the current `IgxSplitterPaneComponent`.
     */
    maxSize: string;
    /**
     * Sets/Gets whether pane is resizable.
     */
    resizable: boolean;
    /**
     * Sets/gets the `order` property of the current `IgxSplitterPaneComponent`.
     */
    order: number;
    /**
     * Gets the host native element.
     * @readonly
     * @type *
     */
    get element(): any;
    /**
     * Sets/gets the `overflow` property of the current `IgxSplitterPaneComponent`.
     */
    overflow: string;
    /**
     * Sets/gets the `minHeight` and `minWidth` propertis of the current `IgxSplitterPaneComponent`.
     */
    minHeight: number;
    /**
     * Sets/gets the `maxHeight` and `maxWidth` propertis of the current `IgxSplitterPaneComponent`.
     */
    maxHeight: string;
    /**
     * Gets the `flex` property of the current `IgxSplitterPaneComponent`.
     * @readonly
     */
    get flex(): string;
    /**
     * Sets/gets the 'display' property of the current `IgxSplitterPaneComponent`
     */
    display: string;
    private _hidden;
    /**
     * Sets/gets whether current `IgxSplitterPanecomponent` is hidden
     */
    set hidden(value: boolean);
    get hidden(): boolean;
    /**
     * Event fired when collapsing and changing the hidden state of the current pane
     */
    onPaneToggle: EventEmitter<IgxSplitterPaneComponent>;
    constructor(el: ElementRef);
}
